dj_anonymizer [![Build Status](https://travis-ci.com/preply/dj_anonymizer.svg?branch=master)](https://travis-ci.com/preply/dj_anonymizer) [![codecov.io](https://codecov.io/github/preply/dj_anonymizer/coverage.svg?branch=master)](https://codecov.io/github/preply/dj_anonymizer?branch=master) [![PyPI version](https://badge.fury.io/py/dj-anonymizer.svg)](https://badge.fury.io/py/dj_anonymizer)
==================================
dj_anonymizer requires Django 1.11 or greater and Python 2.7 or greater.
This project helps anonymize production database with fake data of any kind.

dj_anonymizer uses [django-bulk-update](https://github.com/aykut/django-bulk-update) library for Django<2.2 to be able to process huge massive of data.

Documentation
==================================
[https://dj-anonymizer.readthedocs.io/en/latest/](https://dj-anonymizer.readthedocs.io/en/latest/)
